@@ -8,7 +8,13 @@ use SVG;
 use overload  '""' => \&to_string;
 
 use 5.008000;
-our $VERSION = 0.33;
+our $VERSION = 0.34;
+
+my %valid_parms = map { $_ => 1 } qw(
+        -allns color -sized
+        height width xscale yscale pady padx
+        color bgcolor mark values
+);
 
 sub new
 {
@@ -19,10 +25,9 @@ sub new
     croak "Unrecognized Sparkline type '$type'.\n" if $@;
     croak "Missing arguments hash.\n" unless defined $args;
     croak "Arguments not supplied as a hash reference.\n" unless 'HASH' eq ref $args;
-    # TODO : Add logic to look for unknown parameters and bail.
+    _no_unrecognized_parameters( $type, $args );
 
     my $self = bless {
-        -nodecl => 0,
         -allns => 0,
         color => '#000',
         -sized => 1,
@@ -58,7 +63,6 @@ sub to_string
     my $str = $self->{_SVG}->xmlify();
     # Cleanup
     $str =~ s/ xmlns:(?:svg|xlink)="[^"]+"//g unless $self->{'-allns'};
-    $str =~ s/<\?[^\?]+\?>// if $self->{'-nodecl'};
     unless( $self->{'-sized'} )
     {
         # If I try to keep them from being created, default '100%' values
@@ -72,12 +76,20 @@ sub to_string
 sub _make
 {
     my ($self, $type) = @_;
-    # Disable strict to allow calling method from plugin.
-    no strict 'refs'; ## no critic (ProhibitNoStrict)
     $self->{_SVG} = "SVG::Sparkline::$type"->make( $self );
     return;
 }
 
+sub _no_unrecognized_parameters {
+    my ( $type, $args ) = @_;
+    my $class = "SVG::Sparkline::$type";
+    foreach my $parm (keys %{$args}) {
+        croak "Parameter '$parm' not recognized for '$type'\n"
+            unless exists $valid_parms{$parm} || $class->valid_param( $parm );
+    }
+    return;
+}
+
 sub _validate_pos_param
 {
     my ($self, $name, $default) = @_;
@@ -143,7 +155,7 @@ SVG::Sparkline - Create Sparklines in SVG
 
 =head1 VERSION
 
-This document describes SVG::Sparkline version 0.33
+This document describes SVG::Sparkline version 0.34
 
 =head1 SYNOPSIS
 
