@@ -7,11 +7,15 @@ use SVG;
 use SVG::Sparkline::Utils;
 
 use 5.008000;
-our $VERSION = 0.33;
+our $VERSION = 0.34;
 
 # aliases to make calling shorter.
 *_f = *SVG::Sparkline::Utils::format_f;
 
+sub valid_param {
+    return scalar grep { $_[1] eq $_ } qw/xrange yrange/;
+}
+
 sub make
 {
     my ($class, $args) = @_;
@@ -83,7 +87,7 @@ SVG::Sparkline::Area - Supports SVG::Sparkline for area graphs.
 
 =head1 VERSION
 
-This document describes SVG::Sparkline::Area version 0.33
+This document describes SVG::Sparkline::Area version 0.34
 
 =head1 DESCRIPTION
 
@@ -96,6 +100,11 @@ a 'Area' sparkline. It is loaded on demand by L<SVG::Sparkline>.
 
 Create an L<SVG> object that represents the Area style of Sparkline.
 
+=head2 valid_param
+
+Class method that returns true if the supplied parameter is valid for an
+Area Sparkline.
+
 =head1 DIAGNOSTICS
 
 =over
