@@ -7,11 +7,15 @@ use SVG;
 use SVG::Sparkline::Utils;
 
 use 5.008000;
-our $VERSION = 0.33;
+our $VERSION = 0.34;
 
 # aliases to make calling shorter.
 *_f = *SVG::Sparkline::Utils::format_f;
 
+sub valid_param {
+    return scalar grep { $_[1] eq $_ } qw/thick xrange yrange/;
+}
+
 sub make
 {
     my ($class, $args) = @_;
@@ -76,7 +80,7 @@ SVG::Sparkline::Line - Supports SVG::Sparkline for line graphs.
 
 =head1 VERSION
 
-This document describes SVG::Sparkline::Line version 0.33
+This document describes SVG::Sparkline::Line version 0.34
 
 =head1 DESCRIPTION
 
@@ -89,6 +93,11 @@ a 'Line' sparkline. It is loaded on demand by L<SVG::Sparkline>.
 
 Create an L<SVG> object that represents the Line style of Sparkline.
 
+=head2 valid_param
+
+Class method that returns true if the supplied parameter is valid for an
+Line Sparkline.
+
 =head1 DIAGNOSTICS
 
 =over
